@@ -40,7 +40,7 @@ from robotcode.language_server.common.parts.workspace import FileWatcherEntry, W
 from robotcode.language_server.common.text_document import TextDocument
 from robotcode.language_server.robotframework.configuration import CacheSaveLocation, RobotCodeConfig
 from robotcode.language_server.robotframework.utils.robot_path import find_file_ex
-from robotcode.language_server.robotframework.utils.version import get_robot_version, get_robot_version_str
+from robotcode.robot.utils import get_robot_version, get_robot_version_str
 
 from ...__version__ import __version__
 from .entities import CommandLineVariableDefinition, VariableDefinition
@@ -581,7 +581,7 @@ class ImportsManager:
                     name, args = split_args_from_name_or_path(str(variable_file))
                     try:
                         lib_doc = await self.get_libdoc_for_variables_import(
-                            name,
+                            name.replace("\\", "\\\\"),
                             tuple(args),
                             str(self.folder.to_path()),
                             self,
@@ -1360,7 +1360,7 @@ class ImportsManager:
 
     async def complete_library_import(
         self, name: Optional[str], base_dir: str = ".", variables: Optional[Dict[str, Any]] = None
-    ) -> Optional[List[CompleteResult]]:
+    ) -> List[CompleteResult]:
         return complete_library_import(
             name,
             str(self.folder.to_path()),
